@@ -1,7 +1,7 @@
 OC.L10N.register(
     "dav",
     {
-    "Calendar" : "Kalender",
+    "Calendar" : "Agenda",
     "Todos" : "Te doen",
     "Personal" : "Persoonlijk",
     "{actor} created calendar {calendar}" : "{actor} creëerde agenda {calendar}",
@@ -40,11 +40,12 @@ OC.L10N.register(
     "You solved todo {todo} in list {calendar}" : "Je hebt taak {todo} in lijst {calendar} afgewerkt",
     "{actor} reopened todo {todo} in list {calendar}" : "{actor} heropende taak {todo} in lijst {calendar}",
     "You reopened todo {todo} in list {calendar}" : "Je heropende taak {todo} in lijst {calendar}",
+    "Calendar and tasks" : "Agenda en taken",
     "A <strong>calendar</strong> was modified" : "Een <strong>agenda</strong> is aangepast",
     "A calendar <strong>event</strong> was modified" : "Een agenda <strong>gebeurtenis</strong> is aangepast",
     "A calendar <strong>todo</strong> was modified" : "Een agenda <strong>Te doen</strong> was aangepast",
-    "Death of %s" : "Dood van %s",
     "Contact birthdays" : "Verjaardagen",
+    "Death of %s" : "Sterfdatum van %s",
     "Calendar:" : "Agenda",
     "Date:" : "Datum",
     "Where:" : "Waar:",
@@ -63,26 +64,32 @@ OC.L10N.register(
     "Where: %s" : "Waar: %s",
     "%1$s via %2$s" : "%1$s via %2$s",
     "Invitation canceled" : "Uitnodiging geannuleerd",
-    "Hello %s," : "Hallo %s,",
-    "The meeting »%1$s« with %2$s was canceled." : "De vergadering »%1$s« met %2$s is geannuleerd.",
     "Invitation updated" : "Uitnodiging bijgewerkt",
-    "The meeting »%1$s« with %2$s was updated." : "De vergadering »%1$s« met %2$s is bijgewerkt.",
-    "%1$s invited you to »%2$s«" : "%1$s heeft je uitgenodigd voor »%2$s«",
-    "When:" : "Wanneer:",
+    "Invitation" : "Uitnodiging",
+    "Title:" : "Titel:",
+    "Time:" : "Tijd:",
+    "Location:" : "Locatie:",
     "Link:" : "Link:",
+    "Organizer:" : "Organisator:",
+    "Attendees:" : "Deelnemers:",
     "Accept" : "Accepteren",
     "Decline" : "Afwijzen",
     "More options …" : "Meer opties …",
     "More options at %s" : "Meer opties op %s",
     "Contacts" : "Contactpersonen",
+    "System in maintenance mode." : "Server in onderhoudsmodus.",
+    "Upgrade needed" : "Upgrade vereist",
     "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Je %s moet worden geconfigureerd voor gebruik van HTTPS om CalDAV en CardDAV met iOS/macOS te kunnen gebruiken.",
     "Configures a CalDAV account" : "Configureert een CalDAV account",
     "Configures a CardDAV account" : "Configureert een CardDAV account",
+    "Events" : "Evenementen",
+    "Tasks" : "Taken",
+    "Untitled task" : "Taak zonder titel",
+    "Completed on %s" : "Voltooid op %s",
+    "Due on %s by %s" : "Verwacht op %s door %s",
+    "Due on %s" : "Verwacht op %s",
     "WebDAV" : "WebDAV",
     "WebDAV endpoint" : "WebDAV eindpunt",
-    "Technical details" : "Technische details",
-    "Remote Address: %s" : "Extern adres: %s",
-    "Request ID: %s" : "Aanvraag-ID: %s",
     "There was an error updating your attendance status." : "Er trad een fout op bij het bijwerken van je deelnamestatus.",
     "Please contact the organizer directly." : "Neem rechtstreeks contact op met de organisator.",
     "Are you accepting the invitation?" : "Neem je de uitnodiging aan?",
@@ -97,8 +104,12 @@ OC.L10N.register(
     "Birthday calendars will be generated by a background job." : "Verjaardagkalenders zullen worden gegenereerd in een achtergrond taak.",
     "Hence they will not be available immediately after enabling but will show up after some time." : "Hierdoor zullen ze niet meteen beschikbaar zijn na het inschakelen maar zullen na een tijdje verschijnen.",
     "Send notifications for events" : "Versturen meldingen voor afspraken",
+    "Notifications are sent via background jobs, so these must occur often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden.",
     "Enable notifications for events via push" : "Inschakelen push-melding voor afspraken",
-    "Please make sure to properly set up the email settings above." : "Zorg ervoor dat je de bovenstaande e-mailinstellingen correct instelt.",
-    "Notifications will be send through background jobs, so these need to happen often enough." : "Meldingen worden via achtergrondtaken verstuurd, dus die moeten vaak genoeg plaatsvinden."
+    "Hello %s," : "Hallo %s,",
+    "The meeting »%1$s« with %2$s was canceled." : "De vergadering \"%1$s\" met %2$s is geannuleerd.",
+    "The meeting »%1$s« with %2$s was updated." : "De vergadering \"%1$s\" met %2$s is bijgewerkt.",
+    "%1$s invited you to »%2$s«" : "%1$s heeft je uitgenodigd voor \"%2$s\"",
+    "When:" : "Wanneer:"
 },
 "nplurals=2; plural=(n != 1);");
